Class: Google::Apis::CloudbillingV1beta::AgenticQueryInfo

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudbilling_v1beta/classes.rb,
lib/google/apis/cloudbilling_v1beta/representations.rb,
lib/google/apis/cloudbilling_v1beta/representations.rb

Overview

A local representation of the query used to fetch the data. This is used instead of the raw QueryBillingDataRequest to avoid pulling in Cloud Policy Enforcement (CPE) resource_type annotations into the response payload, which causes ESF validation failures.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AgenticQueryInfo

Returns a new instance of AgenticQueryInfo.



67
68
69
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 67

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#columnsString

The columns queried. Corresponds to the JSON property columns

Returns:

  • (String)


35
36
37
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 35

def columns
  @columns
end

#filterString

The filter applied to the query. Corresponds to the JSON property filter

Returns:

  • (String)


40
41
42
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 40

def filter
  @filter
end

#group_byString

The group-by clause applied to the query. Corresponds to the JSON property groupBy

Returns:

  • (String)


45
46
47
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 45

def group_by
  @group_by
end

#limitFixnum

The row limit applied to the query. Corresponds to the JSON property limit

Returns:

  • (Fixnum)


50
51
52
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 50

def limit
  @limit
end

#order_byString

The order-by clause applied to the query. Corresponds to the JSON property orderBy

Returns:

  • (String)


55
56
57
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 55

def order_by
  @order_by
end

#parentsArray<String>

The parents (e.g. projects, billing accounts) queried. Corresponds to the JSON property parents

Returns:



60
61
62
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 60

def parents
  @parents
end

#viewString

The view queried. Corresponds to the JSON property view

Returns:

  • (String)


65
66
67
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 65

def view
  @view
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



72
73
74
75
76
77
78
79
80
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 72

def update!(**args)
  @columns = args[:columns] if args.key?(:columns)
  @filter = args[:filter] if args.key?(:filter)
  @group_by = args[:group_by] if args.key?(:group_by)
  @limit = args[:limit] if args.key?(:limit)
  @order_by = args[:order_by] if args.key?(:order_by)
  @parents = args[:parents] if args.key?(:parents)
  @view = args[:view] if args.key?(:view)
end