Class: Google::Apis::CloudbillingV1beta::BillingDataResource

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudbilling_v1beta/classes.rb,
lib/google/apis/cloudbilling_v1beta/representations.rb,
lib/google/apis/cloudbilling_v1beta/representations.rb

Overview

Specifies a Billing data resource that can be used for authorization to access billing data.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BillingDataResource

Returns a new instance of BillingDataResource.



145
146
147
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 145

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#billing_accountString

Optional. If not provided the billing account currently associated with the resource will be used. Corresponds to the JSON property billingAccount

Returns:

  • (String)


136
137
138
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 136

def 
  @billing_account
end

#resourceString

Required. Resource name for an entitity that can be used for authorization to access billing data such as projects/projector `billingAccounts/` billing_account Corresponds to the JSON property resource

Returns:

  • (String)


143
144
145
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 143

def resource
  @resource
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



150
151
152
153
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 150

def update!(**args)
  @billing_account = args[:billing_account] if args.key?(:billing_account)
  @resource = args[:resource] if args.key?(:resource)
end