Class: Google::Apis::CloudbillingV1beta::CloudbillingService
- Inherits:
-
Google::Apis::Core::BaseService
- Object
- Google::Apis::Core::BaseService
- Google::Apis::CloudbillingV1beta::CloudbillingService
- Defined in:
- lib/google/apis/cloudbilling_v1beta/service.rb
Overview
Cloud Billing API
Allows developers to manage billing for their Google Cloud Platform projects programmatically.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://cloudbilling.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#generate_insights(generate_insights_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudbillingV1beta::GenerateInsightsResponse
Analyzes cost data for a billing account and/or specific projects.
-
#get_billing_account_service(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudbillingV1beta::GoogleCloudBillingBillingaccountservicesV1betaBillingAccountService
Gets a Google Cloud service visible to a billing account.
-
#get_billing_account_sku(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudbillingV1beta::GoogleCloudBillingBillingaccountskusV1betaBillingAccountSku
Gets a SKU visible to a billing account.
-
#get_billing_account_sku_group(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudbillingV1beta::GoogleCloudBillingBillingaccountskugroupsV1betaBillingAccountSkuGroup
Gets a SKU group visible to a billing account.
-
#get_billing_account_sku_group_sku(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudbillingV1beta::GoogleCloudBillingBillingaccountskugroupskusV1betaBillingAccountSkuGroupSku
Gets a SKU that is part of a billing account SKU group.
-
#get_billing_account_sku_price(name, currency_code: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudbillingV1beta::GoogleCloudBillingBillingaccountpricesV1betaBillingAccountPrice
Gets the latest price for SKUs available to your Cloud Billing account.
-
#get_sku_group(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudbillingV1beta::GoogleCloudBillingSkugroupsV1betaSkuGroup
Gets a publicly listed SKU group.
-
#get_sku_group_sku(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudbillingV1beta::GoogleCloudBillingSkugroupskusV1betaSkuGroupSku
Gets a publicly listed SKU that is part of a publicly listed SKU group.
-
#get_sku_price(name, currency_code: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudbillingV1beta::GoogleCloudBillingPricesV1betaPrice
Gets the latest price for the given SKU.
-
#initialize ⇒ CloudbillingService
constructor
A new instance of CloudbillingService.
-
#list_billing_account_services(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudbillingV1beta::GoogleCloudBillingBillingaccountservicesV1betaListBillingAccountServicesResponse
Lists services visible to a billing account.
-
#list_billing_account_sku_group_skus(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudbillingV1beta::GoogleCloudBillingBillingaccountskugroupskusV1betaListBillingAccountSkuGroupSkusResponse
Lists SKUs that is part of billing account SKU groups.
-
#list_billing_account_sku_groups(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudbillingV1beta::GoogleCloudBillingBillingaccountskugroupsV1betaListBillingAccountSkuGroupsResponse
Lists SKU groups visible to a billing account.
-
#list_billing_account_sku_prices(parent, currency_code: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudbillingV1beta::GoogleCloudBillingBillingaccountpricesV1betaListBillingAccountPricesResponse
Lists the latest prices for SKUs available to your Cloud Billing account.
-
#list_billing_account_skus(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudbillingV1beta::GoogleCloudBillingBillingaccountskusV1betaListBillingAccountSkusResponse
Lists SKUs visible to a billing account.
-
#list_sku_group_skus(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudbillingV1beta::GoogleCloudBillingSkugroupskusV1betaListSkuGroupSkusResponse
Lists all publicly listed SKUs contained by a publicly listed SKU group.
-
#list_sku_groups(page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudbillingV1beta::GoogleCloudBillingSkugroupsV1betaListSkuGroupsResponse
Lists all publicly listed SKU groups.
-
#list_sku_prices(parent, currency_code: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudbillingV1beta::GoogleCloudBillingPricesV1betaListPricesResponse
Lists the latest prices for all SKUs.
Constructor Details
#initialize ⇒ CloudbillingService
Returns a new instance of CloudbillingService.
48 49 50 51 52 53 |
# File 'lib/google/apis/cloudbilling_v1beta/service.rb', line 48 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-cloudbilling_v1beta', client_version: Google::Apis::CloudbillingV1beta::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
41 42 43 |
# File 'lib/google/apis/cloudbilling_v1beta/service.rb', line 41 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
46 47 48 |
# File 'lib/google/apis/cloudbilling_v1beta/service.rb', line 46 def quota_user @quota_user end |
Instance Method Details
#generate_insights(generate_insights_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudbillingV1beta::GenerateInsightsResponse
Analyzes cost data for a billing account and/or specific projects. Returns a natural language summary and supporting datasets.
656 657 658 659 660 661 662 663 664 665 |
# File 'lib/google/apis/cloudbilling_v1beta/service.rb', line 656 def generate_insights(generate_insights_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta:generateInsights', ) command.request_representation = Google::Apis::CloudbillingV1beta::GenerateInsightsRequest::Representation command.request_object = generate_insights_request_object command.response_representation = Google::Apis::CloudbillingV1beta::GenerateInsightsResponse::Representation command.response_class = Google::Apis::CloudbillingV1beta::GenerateInsightsResponse command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_billing_account_service(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudbillingV1beta::GoogleCloudBillingBillingaccountservicesV1betaBillingAccountService
Gets a Google Cloud service visible to a billing account.
76 77 78 79 80 81 82 83 84 |
# File 'lib/google/apis/cloudbilling_v1beta/service.rb', line 76 def get_billing_account_service(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+name}', ) command.response_representation = Google::Apis::CloudbillingV1beta::GoogleCloudBillingBillingaccountservicesV1betaBillingAccountService::Representation command.response_class = Google::Apis::CloudbillingV1beta::GoogleCloudBillingBillingaccountservicesV1betaBillingAccountService command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_billing_account_sku(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudbillingV1beta::GoogleCloudBillingBillingaccountskusV1betaBillingAccountSku
Gets a SKU visible to a billing account.
289 290 291 292 293 294 295 296 297 |
# File 'lib/google/apis/cloudbilling_v1beta/service.rb', line 289 def get_billing_account_sku(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+name}', ) command.response_representation = Google::Apis::CloudbillingV1beta::GoogleCloudBillingBillingaccountskusV1betaBillingAccountSku::Representation command.response_class = Google::Apis::CloudbillingV1beta::GoogleCloudBillingBillingaccountskusV1betaBillingAccountSku command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_billing_account_sku_group(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudbillingV1beta::GoogleCloudBillingBillingaccountskugroupsV1betaBillingAccountSkuGroup
Gets a SKU group visible to a billing account.
147 148 149 150 151 152 153 154 155 |
# File 'lib/google/apis/cloudbilling_v1beta/service.rb', line 147 def get_billing_account_sku_group(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+name}', ) command.response_representation = Google::Apis::CloudbillingV1beta::GoogleCloudBillingBillingaccountskugroupsV1betaBillingAccountSkuGroup::Representation command.response_class = Google::Apis::CloudbillingV1beta::GoogleCloudBillingBillingaccountskugroupsV1betaBillingAccountSkuGroup command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_billing_account_sku_group_sku(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudbillingV1beta::GoogleCloudBillingBillingaccountskugroupskusV1betaBillingAccountSkuGroupSku
Gets a SKU that is part of a billing account SKU group.
218 219 220 221 222 223 224 225 226 |
# File 'lib/google/apis/cloudbilling_v1beta/service.rb', line 218 def get_billing_account_sku_group_sku(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+name}', ) command.response_representation = Google::Apis::CloudbillingV1beta::GoogleCloudBillingBillingaccountskugroupskusV1betaBillingAccountSkuGroupSku::Representation command.response_class = Google::Apis::CloudbillingV1beta::GoogleCloudBillingBillingaccountskugroupskusV1betaBillingAccountSkuGroupSku command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_billing_account_sku_price(name, currency_code: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudbillingV1beta::GoogleCloudBillingBillingaccountpricesV1betaBillingAccountPrice
Gets the latest price for SKUs available to your Cloud Billing account.
368 369 370 371 372 373 374 375 376 377 |
# File 'lib/google/apis/cloudbilling_v1beta/service.rb', line 368 def get_billing_account_sku_price(name, currency_code: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+name}', ) command.response_representation = Google::Apis::CloudbillingV1beta::GoogleCloudBillingBillingaccountpricesV1betaBillingAccountPrice::Representation command.response_class = Google::Apis::CloudbillingV1beta::GoogleCloudBillingBillingaccountpricesV1betaBillingAccountPrice command.params['name'] = name unless name.nil? command.query['currencyCode'] = currency_code unless currency_code.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_sku_group(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudbillingV1beta::GoogleCloudBillingSkugroupsV1betaSkuGroup
Gets a publicly listed SKU group.
444 445 446 447 448 449 450 451 452 |
# File 'lib/google/apis/cloudbilling_v1beta/service.rb', line 444 def get_sku_group(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+name}', ) command.response_representation = Google::Apis::CloudbillingV1beta::GoogleCloudBillingSkugroupsV1betaSkuGroup::Representation command.response_class = Google::Apis::CloudbillingV1beta::GoogleCloudBillingSkugroupsV1betaSkuGroup command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_sku_group_sku(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudbillingV1beta::GoogleCloudBillingSkugroupskusV1betaSkuGroupSku
Gets a publicly listed SKU that is part of a publicly listed SKU group.
510 511 512 513 514 515 516 517 518 |
# File 'lib/google/apis/cloudbilling_v1beta/service.rb', line 510 def get_sku_group_sku(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+name}', ) command.response_representation = Google::Apis::CloudbillingV1beta::GoogleCloudBillingSkugroupskusV1betaSkuGroupSku::Representation command.response_class = Google::Apis::CloudbillingV1beta::GoogleCloudBillingSkugroupskusV1betaSkuGroupSku command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_sku_price(name, currency_code: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudbillingV1beta::GoogleCloudBillingPricesV1betaPrice
Gets the latest price for the given SKU.
581 582 583 584 585 586 587 588 589 590 |
# File 'lib/google/apis/cloudbilling_v1beta/service.rb', line 581 def get_sku_price(name, currency_code: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+name}', ) command.response_representation = Google::Apis::CloudbillingV1beta::GoogleCloudBillingPricesV1betaPrice::Representation command.response_class = Google::Apis::CloudbillingV1beta::GoogleCloudBillingPricesV1betaPrice command.params['name'] = name unless name.nil? command.query['currencyCode'] = currency_code unless currency_code.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_billing_account_services(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudbillingV1beta::GoogleCloudBillingBillingaccountservicesV1betaListBillingAccountServicesResponse
Lists services visible to a billing account.
114 115 116 117 118 119 120 121 122 123 124 |
# File 'lib/google/apis/cloudbilling_v1beta/service.rb', line 114 def list_billing_account_services(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+parent}/services', ) command.response_representation = Google::Apis::CloudbillingV1beta::GoogleCloudBillingBillingaccountservicesV1betaListBillingAccountServicesResponse::Representation command.response_class = Google::Apis::CloudbillingV1beta::GoogleCloudBillingBillingaccountservicesV1betaListBillingAccountServicesResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_billing_account_sku_group_skus(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudbillingV1beta::GoogleCloudBillingBillingaccountskugroupskusV1betaListBillingAccountSkuGroupSkusResponse
Lists SKUs that is part of billing account SKU groups.
256 257 258 259 260 261 262 263 264 265 266 |
# File 'lib/google/apis/cloudbilling_v1beta/service.rb', line 256 def list_billing_account_sku_group_skus(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+parent}/skus', ) command.response_representation = Google::Apis::CloudbillingV1beta::GoogleCloudBillingBillingaccountskugroupskusV1betaListBillingAccountSkuGroupSkusResponse::Representation command.response_class = Google::Apis::CloudbillingV1beta::GoogleCloudBillingBillingaccountskugroupskusV1betaListBillingAccountSkuGroupSkusResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_billing_account_sku_groups(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudbillingV1beta::GoogleCloudBillingBillingaccountskugroupsV1betaListBillingAccountSkuGroupsResponse
Lists SKU groups visible to a billing account.
185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/google/apis/cloudbilling_v1beta/service.rb', line 185 def list_billing_account_sku_groups(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+parent}/skuGroups', ) command.response_representation = Google::Apis::CloudbillingV1beta::GoogleCloudBillingBillingaccountskugroupsV1betaListBillingAccountSkuGroupsResponse::Representation command.response_class = Google::Apis::CloudbillingV1beta::GoogleCloudBillingBillingaccountskugroupsV1betaListBillingAccountSkuGroupsResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_billing_account_sku_prices(parent, currency_code: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudbillingV1beta::GoogleCloudBillingBillingaccountpricesV1betaListBillingAccountPricesResponse
Lists the latest prices for SKUs available to your Cloud Billing account.
411 412 413 414 415 416 417 418 419 420 421 422 |
# File 'lib/google/apis/cloudbilling_v1beta/service.rb', line 411 def list_billing_account_sku_prices(parent, currency_code: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+parent}/prices', ) command.response_representation = Google::Apis::CloudbillingV1beta::GoogleCloudBillingBillingaccountpricesV1betaListBillingAccountPricesResponse::Representation command.response_class = Google::Apis::CloudbillingV1beta::GoogleCloudBillingBillingaccountpricesV1betaListBillingAccountPricesResponse command.params['parent'] = parent unless parent.nil? command.query['currencyCode'] = currency_code unless currency_code.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_billing_account_skus(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudbillingV1beta::GoogleCloudBillingBillingaccountskusV1betaListBillingAccountSkusResponse
Lists SKUs visible to a billing account.
331 332 333 334 335 336 337 338 339 340 341 342 |
# File 'lib/google/apis/cloudbilling_v1beta/service.rb', line 331 def list_billing_account_skus(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+parent}/skus', ) command.response_representation = Google::Apis::CloudbillingV1beta::GoogleCloudBillingBillingaccountskusV1betaListBillingAccountSkusResponse::Representation command.response_class = Google::Apis::CloudbillingV1beta::GoogleCloudBillingBillingaccountskusV1betaListBillingAccountSkusResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_sku_group_skus(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudbillingV1beta::GoogleCloudBillingSkugroupskusV1betaListSkuGroupSkusResponse
Lists all publicly listed SKUs contained by a publicly listed SKU group.
546 547 548 549 550 551 552 553 554 555 556 |
# File 'lib/google/apis/cloudbilling_v1beta/service.rb', line 546 def list_sku_group_skus(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+parent}/skus', ) command.response_representation = Google::Apis::CloudbillingV1beta::GoogleCloudBillingSkugroupskusV1betaListSkuGroupSkusResponse::Representation command.response_class = Google::Apis::CloudbillingV1beta::GoogleCloudBillingSkugroupskusV1betaListSkuGroupSkusResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_sku_groups(page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudbillingV1beta::GoogleCloudBillingSkugroupsV1betaListSkuGroupsResponse
Lists all publicly listed SKU groups.
478 479 480 481 482 483 484 485 486 487 |
# File 'lib/google/apis/cloudbilling_v1beta/service.rb', line 478 def list_sku_groups(page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/skuGroups', ) command.response_representation = Google::Apis::CloudbillingV1beta::GoogleCloudBillingSkugroupsV1betaListSkuGroupsResponse::Representation command.response_class = Google::Apis::CloudbillingV1beta::GoogleCloudBillingSkugroupsV1betaListSkuGroupsResponse command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_sku_prices(parent, currency_code: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudbillingV1beta::GoogleCloudBillingPricesV1betaListPricesResponse
Lists the latest prices for all SKUs.
623 624 625 626 627 628 629 630 631 632 633 634 |
# File 'lib/google/apis/cloudbilling_v1beta/service.rb', line 623 def list_sku_prices(parent, currency_code: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+parent}/prices', ) command.response_representation = Google::Apis::CloudbillingV1beta::GoogleCloudBillingPricesV1betaListPricesResponse::Representation command.response_class = Google::Apis::CloudbillingV1beta::GoogleCloudBillingPricesV1betaListPricesResponse command.params['parent'] = parent unless parent.nil? command.query['currencyCode'] = currency_code unless currency_code.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |