Class: Google::Apis::CloudbillingV1beta::GoogleCloudBillingBillingaccountpricesV1betaRateTier

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudbilling_v1beta/classes.rb,
lib/google/apis/cloudbilling_v1beta/representations.rb,
lib/google/apis/cloudbilling_v1beta/representations.rb

Overview

Encapsulates a rate price tier.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudBillingBillingaccountpricesV1betaRateTier

Returns a new instance of GoogleCloudBillingBillingaccountpricesV1betaRateTier.



819
820
821
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 819

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contract_priceGoogle::Apis::CloudbillingV1beta::Money

Represents an amount of money with its currency type. Corresponds to the JSON property contractPrice



796
797
798
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 796

def contract_price
  @contract_price
end

#effective_discount_percentGoogle::Apis::CloudbillingV1beta::Decimal

A representation of a decimal value, such as 2.5. Clients may convert values into language-native decimal formats, such as Java's BigDecimal or Python's decimal.Decimal. Corresponds to the JSON property effectiveDiscountPercent



804
805
806
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 804

def effective_discount_percent
  @effective_discount_percent
end

#list_priceGoogle::Apis::CloudbillingV1beta::Money

Represents an amount of money with its currency type. Corresponds to the JSON property listPrice



809
810
811
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 809

def list_price
  @list_price
end

#start_amountGoogle::Apis::CloudbillingV1beta::Decimal

A representation of a decimal value, such as 2.5. Clients may convert values into language-native decimal formats, such as Java's BigDecimal or Python's decimal.Decimal. Corresponds to the JSON property startAmount



817
818
819
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 817

def start_amount
  @start_amount
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



824
825
826
827
828
829
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 824

def update!(**args)
  @contract_price = args[:contract_price] if args.key?(:contract_price)
  @effective_discount_percent = args[:effective_discount_percent] if args.key?(:effective_discount_percent)
  @list_price = args[:list_price] if args.key?(:list_price)
  @start_amount = args[:start_amount] if args.key?(:start_amount)
end