Class: Google::Apis::CloudbillingV1beta::GoogleCloudBillingBillingaccountskugroupsV1betaListBillingAccountSkuGroupsResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudbilling_v1beta/classes.rb,
lib/google/apis/cloudbilling_v1beta/representations.rb,
lib/google/apis/cloudbilling_v1beta/representations.rb

Overview

Response message for ListBillingAccountSkuGroups.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudBillingBillingaccountskugroupsV1betaListBillingAccountSkuGroupsResponse

Returns a new instance of GoogleCloudBillingBillingaccountskugroupsV1betaListBillingAccountSkuGroupsResponse.



970
971
972
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 970

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#billing_account_sku_groupsArray<Google::Apis::CloudbillingV1beta::GoogleCloudBillingBillingaccountskugroupsV1betaBillingAccountSkuGroup>

The returned publicly listed billing account SKU groups. Corresponds to the JSON property billingAccountSkuGroups



962
963
964
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 962

def 
  @billing_account_sku_groups
end

#next_page_tokenString

Token that can be sent as page_token in the subsequent request to retrieve the next page. If this field is empty, there are no subsequent pages. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


968
969
970
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 968

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



975
976
977
978
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 975

def update!(**args)
  @billing_account_sku_groups = args[:billing_account_sku_groups] if args.key?(:billing_account_sku_groups)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end