Class: Google::Apis::CloudbillingV1beta::GoogleCloudBillingBillingaccountskugroupskusV1betaBillingAccountSkuGroupSku

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudbilling_v1beta/classes.rb,
lib/google/apis/cloudbilling_v1beta/representations.rb,
lib/google/apis/cloudbilling_v1beta/representations.rb

Overview

Encapsulates a SKU that is part of a billing account SKU group.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudBillingBillingaccountskugroupskusV1betaBillingAccountSkuGroupSku

Returns a new instance of GoogleCloudBillingBillingaccountskugroupskusV1betaBillingAccountSkuGroupSku.



1021
1022
1023
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 1021

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#billing_account_serviceString

BillingAccountService that the BillingAccountSkuGroupSku belongs to. Corresponds to the JSON property billingAccountService

Returns:

  • (String)


988
989
990
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 988

def 
  @billing_account_service
end

#display_nameString

Description of the BillingAccountSkuGroupSku. Example: "A2 Instance Core running in Hong Kong". Corresponds to the JSON property displayName

Returns:

  • (String)


994
995
996
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 994

def display_name
  @display_name
end

#geo_taxonomyGoogle::Apis::CloudbillingV1beta::GoogleCloudBillingBillingaccountskugroupskusV1betaGeoTaxonomy

Encapsulates geographic metadata, such as regions and multi-regions like us- east4 or European Union. Corresponds to the JSON property geoTaxonomy



1000
1001
1002
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 1000

def geo_taxonomy
  @geo_taxonomy
end

#nameString

Resource name for the BillingAccountSkuGroupSku. Example: "billingAccounts/ 012345-567890-ABCDEF/skuGroups/0e6403d1-4694-44d2-a696-7a78b1a69301/skus/AA95- CD31-42FE". Corresponds to the JSON property name

Returns:

  • (String)


1007
1008
1009
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 1007

def name
  @name
end

#product_taxonomyGoogle::Apis::CloudbillingV1beta::GoogleCloudBillingBillingaccountskugroupskusV1betaProductTaxonomy

Encapsulates product categories, such as Serverless, Cloud Run, TaskQueue , and others. Corresponds to the JSON property productTaxonomy



1013
1014
1015
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 1013

def product_taxonomy
  @product_taxonomy
end

#sku_idString

Unique identifier for the SKU. It is the string after the collection identifier "skus/" Example: "AA95-CD31-42FE". Corresponds to the JSON property skuId

Returns:

  • (String)


1019
1020
1021
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 1019

def sku_id
  @sku_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1026
1027
1028
1029
1030
1031
1032
1033
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 1026

def update!(**args)
  @billing_account_service = args[:billing_account_service] if args.key?(:billing_account_service)
  @display_name = args[:display_name] if args.key?(:display_name)
  @geo_taxonomy = args[:geo_taxonomy] if args.key?(:geo_taxonomy)
  @name = args[:name] if args.key?(:name)
  @product_taxonomy = args[:product_taxonomy] if args.key?(:product_taxonomy)
  @sku_id = args[:sku_id] if args.key?(:sku_id)
end