Class: Google::Apis::CloudbillingV1beta::GoogleCloudBillingBillingaccountskugroupskusV1betaGeoTaxonomy
- Inherits:
-
Object
- Object
- Google::Apis::CloudbillingV1beta::GoogleCloudBillingBillingaccountskugroupskusV1betaGeoTaxonomy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudbilling_v1beta/classes.rb,
lib/google/apis/cloudbilling_v1beta/representations.rb,
lib/google/apis/cloudbilling_v1beta/representations.rb
Overview
Encapsulates geographic metadata, such as regions and multi-regions like us-
east4 or European Union.
Instance Attribute Summary collapse
-
#global_metadata ⇒ Google::Apis::CloudbillingV1beta::GoogleCloudBillingBillingaccountskugroupskusV1betaGeoTaxonomyGlobal
Encapsulates a global geographic taxonomy.
-
#multi_regional_metadata ⇒ Google::Apis::CloudbillingV1beta::GoogleCloudBillingBillingaccountskugroupskusV1betaGeoTaxonomyMultiRegional
Encapsulates a multi-regional geographic taxonomy.
-
#regional_metadata ⇒ Google::Apis::CloudbillingV1beta::GoogleCloudBillingBillingaccountskugroupskusV1betaGeoTaxonomyRegional
Encapsulates a regional geographic taxonomy.
-
#type ⇒ String
Type of geographic taxonomy associated with the billing account SKU group SKU.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudBillingBillingaccountskugroupskusV1betaGeoTaxonomy
constructor
A new instance of GoogleCloudBillingBillingaccountskugroupskusV1betaGeoTaxonomy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudBillingBillingaccountskugroupskusV1betaGeoTaxonomy
Returns a new instance of GoogleCloudBillingBillingaccountskugroupskusV1betaGeoTaxonomy.
1061 1062 1063 |
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 1061 def initialize(**args) update!(**args) end |
Instance Attribute Details
#global_metadata ⇒ Google::Apis::CloudbillingV1beta::GoogleCloudBillingBillingaccountskugroupskusV1betaGeoTaxonomyGlobal
Encapsulates a global geographic taxonomy.
Corresponds to the JSON property globalMetadata
1044 1045 1046 |
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 1044 def @global_metadata end |
#multi_regional_metadata ⇒ Google::Apis::CloudbillingV1beta::GoogleCloudBillingBillingaccountskugroupskusV1betaGeoTaxonomyMultiRegional
Encapsulates a multi-regional geographic taxonomy.
Corresponds to the JSON property multiRegionalMetadata
1049 1050 1051 |
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 1049 def @multi_regional_metadata end |
#regional_metadata ⇒ Google::Apis::CloudbillingV1beta::GoogleCloudBillingBillingaccountskugroupskusV1betaGeoTaxonomyRegional
Encapsulates a regional geographic taxonomy.
Corresponds to the JSON property regionalMetadata
1054 1055 1056 |
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 1054 def @regional_metadata end |
#type ⇒ String
Type of geographic taxonomy associated with the billing account SKU group SKU.
Corresponds to the JSON property type
1059 1060 1061 |
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 1059 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1066 1067 1068 1069 1070 1071 |
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 1066 def update!(**args) @global_metadata = args[:global_metadata] if args.key?(:global_metadata) @multi_regional_metadata = args[:multi_regional_metadata] if args.key?(:multi_regional_metadata) @regional_metadata = args[:regional_metadata] if args.key?(:regional_metadata) @type = args[:type] if args.key?(:type) end |