Class: Google::Apis::CloudbillingV1beta::GoogleCloudBillingSkugroupskusV1betaSkuGroupSku

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudbilling_v1beta/classes.rb,
lib/google/apis/cloudbilling_v1beta/representations.rb,
lib/google/apis/cloudbilling_v1beta/representations.rb

Overview

Encapsulates a publicly listed stock keeping unit (SKU) that is part of a publicly listed SKU group. A SKU group represents a collection of SKUs that are related to each other. For example, the AI Platform APIs SKU group includes SKUs from the Cloud Dialogflow API, the Cloud Text-to-Speech API, and additional related APIs.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudBillingSkugroupskusV1betaSkuGroupSku

Returns a new instance of GoogleCloudBillingSkugroupskusV1betaSkuGroupSku.



1877
1878
1879
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 1877

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Description of the SkuGroupSku. Example: "A2 Instance Core running in Hong Kong". Corresponds to the JSON property displayName

Returns:

  • (String)


1846
1847
1848
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 1846

def display_name
  @display_name
end

#geo_taxonomyGoogle::Apis::CloudbillingV1beta::GoogleCloudBillingSkugroupskusV1betaGeoTaxonomy

Encapsulates geographic metadata, such as regions and multi-regions like us- east4 or European Union. Corresponds to the JSON property geoTaxonomy



1852
1853
1854
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 1852

def geo_taxonomy
  @geo_taxonomy
end

#nameString

Resource name for the SkuGroupSku. Example: "skuGroups/0e6403d1-4694-44d2-a696- 7a78b1a69301/skus/AA95-CD31-42FE". Corresponds to the JSON property name

Returns:

  • (String)


1858
1859
1860
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 1858

def name
  @name
end

#product_taxonomyGoogle::Apis::CloudbillingV1beta::GoogleCloudBillingSkugroupskusV1betaProductTaxonomy

Encapsulates product categories, such as Serverless, Cloud Run, TaskQueue , and others. Corresponds to the JSON property productTaxonomy



1864
1865
1866
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 1864

def product_taxonomy
  @product_taxonomy
end

#serviceString

Service that the SkuGroupSku belongs to. Corresponds to the JSON property service

Returns:

  • (String)


1869
1870
1871
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 1869

def service
  @service
end

#sku_idString

Unique identifier for the SKU. It is the string after the collection identifier "skus/" Example: "AA95-CD31-42FE". Corresponds to the JSON property skuId

Returns:

  • (String)


1875
1876
1877
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 1875

def sku_id
  @sku_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1882
1883
1884
1885
1886
1887
1888
1889
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 1882

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @geo_taxonomy = args[:geo_taxonomy] if args.key?(:geo_taxonomy)
  @name = args[:name] if args.key?(:name)
  @product_taxonomy = args[:product_taxonomy] if args.key?(:product_taxonomy)
  @service = args[:service] if args.key?(:service)
  @sku_id = args[:sku_id] if args.key?(:sku_id)
end