Class: Google::Apis::CloudbillingV1beta::MapEntry

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudbilling_v1beta/classes.rb,
lib/google/apis/cloudbilling_v1beta/representations.rb,
lib/google/apis/cloudbilling_v1beta/representations.rb

Overview

A single entry in a Map, representing the mapping between key and value.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MapEntry

Returns a new instance of MapEntry.



2025
2026
2027
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 2025

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#keyGoogle::Apis::CloudbillingV1beta::ValueProto

This is a copy of storage/googlesql/public/value.proto. ValueProto represents the serialized form of the googlesql::Value. The intention is to support multiple languages including Java and C++, so we must be sensitive to the distinction between Java Strings and byte arrays or ByteStrings. We also want to support use-cases which do not want to serialize a copy of the GoogleSQL type for every instance (which might be very repetitive). Therefore, unlike googlesql::Value, ValueProto does not carry full type information with every instance, and can only be fully interpreted with an associated TypeProto. Corresponds to the JSON property key



2011
2012
2013
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 2011

def key
  @key
end

#valueGoogle::Apis::CloudbillingV1beta::ValueProto

This is a copy of storage/googlesql/public/value.proto. ValueProto represents the serialized form of the googlesql::Value. The intention is to support multiple languages including Java and C++, so we must be sensitive to the distinction between Java Strings and byte arrays or ByteStrings. We also want to support use-cases which do not want to serialize a copy of the GoogleSQL type for every instance (which might be very repetitive). Therefore, unlike googlesql::Value, ValueProto does not carry full type information with every instance, and can only be fully interpreted with an associated TypeProto. Corresponds to the JSON property value



2023
2024
2025
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 2023

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2030
2031
2032
2033
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 2030

def update!(**args)
  @key = args[:key] if args.key?(:key)
  @value = args[:value] if args.key?(:value)
end