Class: Google::Apis::CloudbillingV1beta::DataSet
- Inherits:
-
Object
- Object
- Google::Apis::CloudbillingV1beta::DataSet
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudbilling_v1beta/classes.rb,
lib/google/apis/cloudbilling_v1beta/representations.rb,
lib/google/apis/cloudbilling_v1beta/representations.rb
Overview
A dataset used to support an insight, suitable for UI rendering (tables/charts) .
Instance Attribute Summary collapse
-
#billing_data ⇒ Google::Apis::CloudbillingV1beta::BillingData
Encapsulates billing data.
-
#query_info ⇒ Google::Apis::CloudbillingV1beta::AgenticQueryInfo
A local representation of the query used to fetch the data.
-
#suggested_chart ⇒ Google::Apis::CloudbillingV1beta::SuggestedChart
A suggested chart for the data set, used for UI rendering.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DataSet
constructor
A new instance of DataSet.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DataSet
Returns a new instance of DataSet.
198 199 200 |
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 198 def initialize(**args) update!(**args) end |
Instance Attribute Details
#billing_data ⇒ Google::Apis::CloudbillingV1beta::BillingData
Encapsulates billing data.
Corresponds to the JSON property billingData
183 184 185 |
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 183 def billing_data @billing_data end |
#query_info ⇒ Google::Apis::CloudbillingV1beta::AgenticQueryInfo
A local representation of the query used to fetch the data. This is used
instead of the raw QueryBillingDataRequest to avoid pulling in Cloud Policy
Enforcement (CPE) resource_type annotations into the response payload, which
causes ESF validation failures.
Corresponds to the JSON property queryInfo
191 192 193 |
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 191 def query_info @query_info end |
#suggested_chart ⇒ Google::Apis::CloudbillingV1beta::SuggestedChart
A suggested chart for the data set, used for UI rendering.
Corresponds to the JSON property suggestedChart
196 197 198 |
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 196 def suggested_chart @suggested_chart end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
203 204 205 206 207 |
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 203 def update!(**args) @billing_data = args[:billing_data] if args.key?(:billing_data) @query_info = args[:query_info] if args.key?(:query_info) @suggested_chart = args[:suggested_chart] if args.key?(:suggested_chart) end |