Class: Google::Apis::CloudbillingV1beta::FinalResult
- Inherits:
-
Object
- Object
- Google::Apis::CloudbillingV1beta::FinalResult
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudbilling_v1beta/classes.rb,
lib/google/apis/cloudbilling_v1beta/representations.rb,
lib/google/apis/cloudbilling_v1beta/representations.rb
Overview
Encapsulates all structured data and the completed summary.
Instance Attribute Summary collapse
-
#data_sets ⇒ Array<Google::Apis::CloudbillingV1beta::DataSet>
Output only.
-
#full_analysis ⇒ String
Output only.
-
#insights ⇒ Array<Google::Apis::CloudbillingV1beta::Insight>
Output only.
-
#interop_links ⇒ Array<Google::Apis::CloudbillingV1beta::InteropLink>
Output only.
-
#suggested_queries ⇒ Array<Google::Apis::CloudbillingV1beta::SuggestedQuery>
Output only.
-
#summary ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FinalResult
constructor
A new instance of FinalResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FinalResult
Returns a new instance of FinalResult.
329 330 331 |
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 329 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data_sets ⇒ Array<Google::Apis::CloudbillingV1beta::DataSet>
Output only. Data sets used to support the insights, suitable for UI rendering
(tables/charts).
Corresponds to the JSON property dataSets
300 301 302 |
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 300 def data_sets @data_sets end |
#full_analysis ⇒ String
Output only. Contains the full natural language analysis, including thoughts,
reasoning, and references.
Corresponds to the JSON property fullAnalysis
306 307 308 |
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 306 def full_analysis @full_analysis end |
#insights ⇒ Array<Google::Apis::CloudbillingV1beta::Insight>
Output only. A list of discrete insights gleaned from the data.
Corresponds to the JSON property insights
311 312 313 |
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 311 def insights @insights end |
#interop_links ⇒ Array<Google::Apis::CloudbillingV1beta::InteropLink>
Output only. Links to interoperable tools (e.g., pre-filtered Cost Reports or
BQE queries).
Corresponds to the JSON property interopLinks
317 318 319 |
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 317 def interop_links @interop_links end |
#suggested_queries ⇒ Array<Google::Apis::CloudbillingV1beta::SuggestedQuery>
Output only. A list of suggested follow-up queries for the user.
Corresponds to the JSON property suggestedQueries
322 323 324 |
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 322 def suggested_queries @suggested_queries end |
#summary ⇒ String
Output only. The full natural language summary (re-sent for consistency).
Corresponds to the JSON property summary
327 328 329 |
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 327 def summary @summary end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
334 335 336 337 338 339 340 341 |
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 334 def update!(**args) @data_sets = args[:data_sets] if args.key?(:data_sets) @full_analysis = args[:full_analysis] if args.key?(:full_analysis) @insights = args[:insights] if args.key?(:insights) @interop_links = args[:interop_links] if args.key?(:interop_links) @suggested_queries = args[:suggested_queries] if args.key?(:suggested_queries) @summary = args[:summary] if args.key?(:summary) end |