Class: Google::Apis::CloudbillingV1beta::GoogleCloudBillingBillingaccountpricesV1betaFloatingDiscount
- Inherits:
-
Object
- Object
- Google::Apis::CloudbillingV1beta::GoogleCloudBillingBillingaccountpricesV1betaFloatingDiscount
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudbilling_v1beta/classes.rb,
lib/google/apis/cloudbilling_v1beta/representations.rb,
lib/google/apis/cloudbilling_v1beta/representations.rb
Overview
Encapsulates a discount off the current list price, not anchored to any list price as of a fixed time.
Instance Attribute Summary collapse
-
#discount_percent ⇒ Google::Apis::CloudbillingV1beta::Decimal
A representation of a decimal value, such as 2.5.
-
#discount_scope_type ⇒ String
Type of the floating discount scope which indicates the source of the discount.
-
#sku_group ⇒ String
SKU group where the floating discount comes from.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudBillingBillingaccountpricesV1betaFloatingDiscount
constructor
A new instance of GoogleCloudBillingBillingaccountpricesV1betaFloatingDiscount.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudBillingBillingaccountpricesV1betaFloatingDiscount
Returns a new instance of GoogleCloudBillingBillingaccountpricesV1betaFloatingDiscount.
593 594 595 |
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 593 def initialize(**args) update!(**args) end |
Instance Attribute Details
#discount_percent ⇒ Google::Apis::CloudbillingV1beta::Decimal
A representation of a decimal value, such as 2.5. Clients may convert values
into language-native decimal formats, such as Java's BigDecimal or
Python's decimal.Decimal.
Corresponds to the JSON property discountPercent
580 581 582 |
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 580 def discount_percent @discount_percent end |
#discount_scope_type ⇒ String
Type of the floating discount scope which indicates the source of the discount.
It can have values such as 'unspecified' and 'sku-group'.
Corresponds to the JSON property discountScopeType
586 587 588 |
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 586 def discount_scope_type @discount_scope_type end |
#sku_group ⇒ String
SKU group where the floating discount comes from.
Corresponds to the JSON property skuGroup
591 592 593 |
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 591 def sku_group @sku_group end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
598 599 600 601 602 |
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 598 def update!(**args) @discount_percent = args[:discount_percent] if args.key?(:discount_percent) @discount_scope_type = args[:discount_scope_type] if args.key?(:discount_scope_type) @sku_group = args[:sku_group] if args.key?(:sku_group) end |