Class: Google::Apis::CloudbillingV1beta::GoogleCloudBillingBillingaccountskusV1betaBillingAccountSku
- Inherits:
-
Object
- Object
- Google::Apis::CloudbillingV1beta::GoogleCloudBillingBillingaccountskusV1betaBillingAccountSku
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudbilling_v1beta/classes.rb,
lib/google/apis/cloudbilling_v1beta/representations.rb,
lib/google/apis/cloudbilling_v1beta/representations.rb
Overview
Encapsulates a stock keeping unit (SKU) visible to a billing account. A SKU distinctly identifies a resource that you can purchase. For a list of available SKUs, see SKUs.
Instance Attribute Summary collapse
-
#billing_account_service ⇒ String
BillingAccountService that the BillingAccountSku belongs to.
-
#display_name ⇒ String
Description of the BillingAccountSku.
-
#geo_taxonomy ⇒ Google::Apis::CloudbillingV1beta::GoogleCloudBillingBillingaccountskusV1betaGeoTaxonomy
Encapsulates geographic metadata, such as regions and multi-regions like
us- east4orEuropean Union. -
#name ⇒ String
Resource name for the BillingAccountSku.
-
#product_taxonomy ⇒ Google::Apis::CloudbillingV1beta::GoogleCloudBillingBillingaccountskusV1betaProductTaxonomy
Encapsulates product categories, such as
Serverless,Cloud Run,TaskQueue, and others. -
#sku_id ⇒ String
Unique identifier for the SKU.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudBillingBillingaccountskusV1betaBillingAccountSku
constructor
A new instance of GoogleCloudBillingBillingaccountskusV1betaBillingAccountSku.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudBillingBillingaccountskusV1betaBillingAccountSku
Returns a new instance of GoogleCloudBillingBillingaccountskusV1betaBillingAccountSku.
1250 1251 1252 |
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 1250 def initialize(**args) update!(**args) end |
Instance Attribute Details
#billing_account_service ⇒ String
BillingAccountService that the BillingAccountSku belongs to.
Corresponds to the JSON property billingAccountService
1218 1219 1220 |
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 1218 def billing_account_service @billing_account_service end |
#display_name ⇒ String
Description of the BillingAccountSku. Example: "A2 Instance Core running in
Hong Kong".
Corresponds to the JSON property displayName
1224 1225 1226 |
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 1224 def display_name @display_name end |
#geo_taxonomy ⇒ Google::Apis::CloudbillingV1beta::GoogleCloudBillingBillingaccountskusV1betaGeoTaxonomy
Encapsulates geographic metadata, such as regions and multi-regions like us-
east4 or European Union.
Corresponds to the JSON property geoTaxonomy
1230 1231 1232 |
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 1230 def geo_taxonomy @geo_taxonomy end |
#name ⇒ String
Resource name for the BillingAccountSku. Example: "billingAccounts/012345-
567890-ABCDEF/skus/AA95-CD31-42FE".
Corresponds to the JSON property name
1236 1237 1238 |
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 1236 def name @name end |
#product_taxonomy ⇒ Google::Apis::CloudbillingV1beta::GoogleCloudBillingBillingaccountskusV1betaProductTaxonomy
Encapsulates product categories, such as Serverless, Cloud Run, TaskQueue
, and others.
Corresponds to the JSON property productTaxonomy
1242 1243 1244 |
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 1242 def product_taxonomy @product_taxonomy end |
#sku_id ⇒ String
Unique identifier for the SKU. It is the string after the collection
identifier "skus/" Example: "AA95-CD31-42FE".
Corresponds to the JSON property skuId
1248 1249 1250 |
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 1248 def sku_id @sku_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1255 1256 1257 1258 1259 1260 1261 1262 |
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 1255 def update!(**args) @billing_account_service = args[:billing_account_service] if args.key?(:billing_account_service) @display_name = args[:display_name] if args.key?(:display_name) @geo_taxonomy = args[:geo_taxonomy] if args.key?(:geo_taxonomy) @name = args[:name] if args.key?(:name) @product_taxonomy = args[:product_taxonomy] if args.key?(:product_taxonomy) @sku_id = args[:sku_id] if args.key?(:sku_id) end |