Class: Google::Apis::CloudbillingV1beta::Money
- Inherits:
-
Object
- Object
- Google::Apis::CloudbillingV1beta::Money
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudbilling_v1beta/classes.rb,
lib/google/apis/cloudbilling_v1beta/representations.rb,
lib/google/apis/cloudbilling_v1beta/representations.rb
Overview
Represents an amount of money with its currency type.
Instance Attribute Summary collapse
-
#currency_code ⇒ String
The three-letter currency code defined in ISO 4217.
-
#nanos ⇒ Fixnum
Number of nano (10^-9) units of the amount.
-
#units ⇒ Fixnum
The whole units of the amount.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Money
constructor
A new instance of Money.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Money
Returns a new instance of Money.
2060 2061 2062 |
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 2060 def initialize(**args) update!(**args) end |
Instance Attribute Details
#currency_code ⇒ String
The three-letter currency code defined in ISO 4217.
Corresponds to the JSON property currencyCode
2043 2044 2045 |
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 2043 def currency_code @currency_code end |
#nanos ⇒ Fixnum
Number of nano (10^-9) units of the amount. The value must be between -999,999,
999 and +999,999,999 inclusive. If units is positive, nanos must be
positive or zero. If units is zero, nanos can be positive, zero, or
negative. If units is negative, nanos must be negative or zero. For
example $-1.75 is represented as units=-1 and nanos=-750,000,000.
Corresponds to the JSON property nanos
2052 2053 2054 |
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 2052 def nanos @nanos end |
#units ⇒ Fixnum
The whole units of the amount. For example if currencyCode is "USD", then
1 unit is one US dollar.
Corresponds to the JSON property units
2058 2059 2060 |
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 2058 def units @units end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2065 2066 2067 2068 2069 |
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 2065 def update!(**args) @currency_code = args[:currency_code] if args.key?(:currency_code) @nanos = args[:nanos] if args.key?(:nanos) @units = args[:units] if args.key?(:units) end |