Class: Google::Apis::CloudbillingV1beta::Range
- Inherits:
-
Object
- Object
- Google::Apis::CloudbillingV1beta::Range
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudbilling_v1beta/classes.rb,
lib/google/apis/cloudbilling_v1beta/representations.rb,
lib/google/apis/cloudbilling_v1beta/representations.rb
Overview
A range of values, bounded by the values 'start' (inclusive) and 'end' ( exclusive). A range has an element type, and values must be of this element type. A range is contiguous, ie it contains all values of the given element type starting at 'start' and ending before 'end'. A "null" value on start or end represents an unbounded start or end value respectively. Start and end values must always be present.
Instance Attribute Summary collapse
-
#end ⇒ Google::Apis::CloudbillingV1beta::ValueProto
This is a copy of storage/googlesql/public/value.proto.
-
#start ⇒ Google::Apis::CloudbillingV1beta::ValueProto
This is a copy of storage/googlesql/public/value.proto.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Range
constructor
A new instance of Range.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Range
Returns a new instance of Range.
2105 2106 2107 |
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 2105 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end ⇒ Google::Apis::CloudbillingV1beta::ValueProto
This is a copy of storage/googlesql/public/value.proto. ValueProto represents
the serialized form of the googlesql::Value. The intention is to support
multiple languages including Java and C++, so we must be sensitive to the
distinction between Java Strings and byte arrays or ByteStrings. We also want
to support use-cases which do not want to serialize a copy of the GoogleSQL
type for every instance (which might be very repetitive). Therefore, unlike
googlesql::Value, ValueProto does not carry full type information with every
instance, and can only be fully interpreted with an associated TypeProto.
Corresponds to the JSON property end
2091 2092 2093 |
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 2091 def end @end end |
#start ⇒ Google::Apis::CloudbillingV1beta::ValueProto
This is a copy of storage/googlesql/public/value.proto. ValueProto represents
the serialized form of the googlesql::Value. The intention is to support
multiple languages including Java and C++, so we must be sensitive to the
distinction between Java Strings and byte arrays or ByteStrings. We also want
to support use-cases which do not want to serialize a copy of the GoogleSQL
type for every instance (which might be very repetitive). Therefore, unlike
googlesql::Value, ValueProto does not carry full type information with every
instance, and can only be fully interpreted with an associated TypeProto.
Corresponds to the JSON property start
2103 2104 2105 |
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 2103 def start @start end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2110 2111 2112 2113 |
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 2110 def update!(**args) @end = args[:end] if args.key?(:end) @start = args[:start] if args.key?(:start) end |