Class: Google::Apis::CloudbillingV1beta::Struct
- Inherits:
-
Object
- Object
- Google::Apis::CloudbillingV1beta::Struct
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudbilling_v1beta/classes.rb,
lib/google/apis/cloudbilling_v1beta/representations.rb,
lib/google/apis/cloudbilling_v1beta/representations.rb
Overview
A collection of fields. The count, order, and type of the fields is determined by the type associated with this value.
Instance Attribute Summary collapse
-
#field ⇒ Array<Google::Apis::CloudbillingV1beta::ValueProto>
The fields in the struct Corresponds to the JSON property
field.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Struct
constructor
A new instance of Struct.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Struct
Returns a new instance of Struct.
2170 2171 2172 |
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 2170 def initialize(**args) update!(**args) end |
Instance Attribute Details
#field ⇒ Array<Google::Apis::CloudbillingV1beta::ValueProto>
The fields in the struct
Corresponds to the JSON property field
2168 2169 2170 |
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 2168 def field @field end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2175 2176 2177 |
# File 'lib/google/apis/cloudbilling_v1beta/classes.rb', line 2175 def update!(**args) @field = args[:field] if args.key?(:field) end |